@@ -115,9 +115,12 @@ def validate_model(orga, model):
             dataset,
             steps=len(val_generator),
             max_queue_size=orga.cfg.max_queue_size,
-            verbose=orga.cfg.verbose_val)
+            verbose=orga.cfg.verbose_val,
+        )
         if not isinstance(history_file, list):
-            history_file = [history_file, ]
+            history_file = [
+                history_file,
+            ]
         histories.append(history_file)
 
     # average over all val files
@@ -152,13 +155,15 @@ def weighted_average(histories, f_sizes):
 
     """
     assert len(histories) == len(f_sizes)
-    rltv_fsizes = [f_size/sum(f_sizes) for f_size in f_sizes]
+    rltv_fsizes = [f_size / sum(f_sizes) for f_size in f_sizes]
     wgtd_average = np.dot(np.transpose(histories), rltv_fsizes)
 
     return wgtd_average.tolist()
 
 
-def h5_inference(orga, model, files_dict, output_path, samples=None, use_def_label=True):
+def h5_inference(
+    orga, model, files_dict, output_path, samples=None, use_def_label=True
+):
     """
     Let a model predict on all samples in a h5 file, and save it as a h5 file.
 
@@ -185,8 +190,8 @@ def h5_inference(orga, model, files_dict, output_path, samples=None, use_def_lab
 
     """
     file_size = h5_get_number_of_rows(
-        list(files_dict.values())[0],
-        datasets=[orga.cfg.key_y_values])
+        list(files_dict.values())[0], datasets=[orga.cfg.key_y_values]
+    )
     generator = h5_generator.get_h5_generator(
         orga,
         files_dict,
@@ -195,82 +200,89 @@ def h5_inference(orga, model, files_dict, output_path, samples=None, use_def_lab
         use_def_label=use_def_label,
         phase="inference",
     )
-    itergen = iter(generator)
+    try:
+        itergen = iter(generator)
 
-    if samples is None:
-        steps = len(generator)
-    else:
-        steps = int(samples / orga.cfg.batchsize)
-    print_every = max(100, min(int(round(steps/10, -2)), 1000))
-    model_time_total = 0.
-    dataset_last_element = {}
+        if samples is None:
+            steps = len(generator)
+        else:
+            steps = int(samples / orga.cfg.batchsize)
+        print_every = max(100, min(int(round(steps / 10, -2)), 1000))
+        model_time_total = 0.0
+        dataset_last_element = {}
 
-    temp_output_path = os.path.join(
-        os.path.dirname(output_path),
-        "temp_" + os.path.basename(output_path) + "_" +
-        time.strftime("%d-%m-%Y-%H-%M-%S", time.gmtime()))
-    print(f"Creating temporary file {temp_output_path}")
-    with h5py.File(temp_output_path, 'x') as h5_file:
-        # add version and paths of h5files
-        h5_file.attrs.create("orcanet", orcanet.__version__)
-        for input_key, file in files_dict.items():
-            h5_file.attrs.create(f"orcanet_inp_{input_key}", file)
+        temp_output_path = os.path.join(
+            os.path.dirname(output_path),
+            "temp_"
+            + os.path.basename(output_path)
+            + "_"
+            + time.strftime("%d-%m-%Y-%H-%M-%S", time.gmtime()),
+        )
+        print(f"Creating temporary file {temp_output_path}")
+        with h5py.File(temp_output_path, "x") as h5_file:
+            # add version and paths of h5files
+            h5_file.attrs.create("orcanet", orcanet.__version__)
+            for input_key, file in files_dict.items():
+                h5_file.attrs.create(f"orcanet_inp_{input_key}", file)
 
-        for s in range(steps):
-            if s % print_every == 0:
-                print('Predicting in step {}/{} ({:0.2%})'.format(
-                    s, steps, s/steps))
-
-            info_blob = next(itergen)
-
-            start_time = time.time()
-            y_pred = model.predict_on_batch(info_blob["xs"])
-            model_time_total += time.time() - start_time
-
-            if not isinstance(y_pred, list):
-                # if only one output, transform to a list
-                y_pred = [y_pred]
-            # transform y_pred to dict
-            y_pred = {
-                out: y_pred[i] for i, out in enumerate(model.output_names)}
-            info_blob["y_pred"] = y_pred
-
-            if info_blob.get("org_batchsize") is not None:
-                _slice_to_size(info_blob)
-
-            if orga.cfg.dataset_modifier is None:
-                datasets = dataset_modifiers.as_array(info_blob)
-            else:
-                datasets = orga.cfg.dataset_modifier(info_blob)
-
-            if s == 0:  # create datasets in the first step
-                for dataset_name, data in datasets.items():
-                    dset = h5_file.create_dataset(
-                        dataset_name,
-                        data=data,
-                        maxshape=(file_size,) + data.shape[1:],
-                        chunks=True,  # (batchsize,) + data.shape[1:]
-                        compression="gzip",
-                        compression_opts=1,
-                        # shuffle = True,  TODO ?
+            for s in range(steps):
+                if s % print_every == 0:
+                    print(
+                        "Predicting in step {}/{} ({:0.2%})".format(s, steps, s / steps)
                     )
-                    dset.resize(file_size, axis=0)
-                    dataset_last_element[dataset_name] = data.shape[0]
-            else:
+
+                info_blob = next(itergen)
+
+                start_time = time.time()
+                y_pred = model.predict_on_batch(info_blob["xs"])
+                model_time_total += time.time() - start_time
+
+                if not isinstance(y_pred, list):
+                    # if only one output, transform to a list
+                    y_pred = [y_pred]
+                # transform y_pred to dict
+                y_pred = {out: y_pred[i] for i, out in enumerate(model.output_names)}
+                info_blob["y_pred"] = y_pred
+
+                if info_blob.get("org_batchsize") is not None:
+                    _slice_to_size(info_blob)
+
+                if orga.cfg.dataset_modifier is None:
+                    datasets = dataset_modifiers.as_array(info_blob)
+                else:
+                    datasets = orga.cfg.dataset_modifier(info_blob)
+
                 for dataset_name, data in datasets.items():
+                    if s == 0:
+                        # create datasets in the first step
+                        h5_file.create_dataset(
+                            dataset_name,
+                            shape=(file_size,) + data.shape[1:],
+                            dtype=data.dtype,
+                            chunks=True,
+                            compression="gzip",
+                            compression_opts=1,
+                            shuffle=True,
+                        )
+                        dataset_last_element[dataset_name] = 0
+
                     ix = dataset_last_element[dataset_name]
-                    h5_file[dataset_name][ix:ix+data.shape[0]:] = data
+                    h5_file[dataset_name][ix : (ix + data.shape[0])] = data
                     dataset_last_element[dataset_name] += data.shape[0]
+    finally:
+        generator.close()
 
     if os.path.exists(output_path):
         raise FileExistsError(
             f"{output_path} exists already! But file {temp_output_path} "
-            f"is finished and can be safely used.")
+            f"is finished and can be safely used."
+        )
     os.rename(temp_output_path, output_path)
-    generator.print_timestats()
-    print("Statistics of model prediction:")
-    print(f"\tTotal time:\t{model_time_total / 60:.2f} min")
-    print(f"\tPer batch:\t{1000 * model_time_total / steps:.5} ms")
+    orga.io.print_log(f"\nPrediction completed on file {os.path.basename(output_path)}")
+    orga.io.print_log("Statistics of model prediction:")
+    orga.io.print_log(f"\tTotal time:\t{model_time_total / 60:.2f} min")
+    orga.io.print_log(f"\tPer batch:\t{1000 * model_time_total / steps:.5} ms")
+    generator.print_timestats(print_func=orga.io.print_log)
 
 
 def _slice_to_size(info_blob):
