@@ -43,7 +43,7 @@ def get_subfolder(main_folder, name=None, create=False):
         "plots": main_folder + "plots",
         "activations": main_folder + "plots/activations",
         "predictions": main_folder + "predictions",
-        "inference": main_folder + "predictions/inference"
+        "inference": main_folder + "predictions/inference",
     }
 
     def get(fdr):
@@ -61,8 +61,7 @@ def get_subfolder(main_folder, name=None, create=False):
 
 
 def get_inputs(model):
-    """ Get names and keras layers of the inputs of the model, as a dict.
-    """
+    """Get names and keras layers of the inputs of the model, as a dict."""
     return {name: model.get_layer(name) for name in model.input_names}
 
 
@@ -70,6 +69,7 @@ class IOHandler(object):
     """
     Access info indirectly contained in the cfg object.
     """
+
     def __init__(self, cfg):
         self.cfg = cfg
 
@@ -114,14 +114,13 @@ class IOHandler(object):
         if os.path.exists(saved_models_folder):
             files = []
             for file in os.listdir(saved_models_folder):
-                if file.startswith("model_epoch_") and file.endswith('.h5'):
+                if file.startswith("model_epoch_") and file.endswith(".h5"):
                     files.append(file)
 
             for file in files:
                 # model_epoch_XX_file_YY
                 file_base = os.path.splitext(file)[0]
-                f_epoch, file_no = file_base.split(
-                    "model_epoch_")[-1].split("_file_")
+                f_epoch, file_no = file_base.split("model_epoch_")[-1].split("_file_")
                 epochs.append((int(f_epoch), int(file_no)))
             epochs.sort()
 
@@ -153,15 +152,17 @@ class IOHandler(object):
         return next_epoch
 
     def get_previous_epoch(self, epoch):
-        """ Return the previous epoch / fileno tuple. """
+        """Return the previous epoch / fileno tuple."""
         if epoch[1] == 1:
             if epoch[0] == 1:
-                raise ValueError("Can not get previous epoch of epoch {} file {}".format(*epoch))
+                raise ValueError(
+                    "Can not get previous epoch of epoch {} file {}".format(*epoch)
+                )
             n_train_files = self.get_no_of_files("train")
-            prev_epoch = (epoch[0]-1, n_train_files)
+            prev_epoch = (epoch[0] - 1, n_train_files)
 
         else:
-            prev_epoch = (epoch[0], epoch[1]-1)
+            prev_epoch = (epoch[0], epoch[1] - 1)
 
         return prev_epoch
 
@@ -208,13 +209,15 @@ class IOHandler(object):
         if epoch == -1 and fileno == -1:
             epoch, fileno = self.get_latest_epoch()
         if epoch < 1 or fileno < 1:
-            raise ValueError("Invalid epoch/file number {}, {}: Must be "
-                             "either (-1, -1) or both >0".format(epoch, fileno))
+            raise ValueError(
+                "Invalid epoch/file number {}, {}: Must be "
+                "either (-1, -1) or both >0".format(epoch, fileno)
+            )
 
         subfolder = self.get_subfolder("saved_models")
         if local:
             subfolder = subfolder.split("/")[-1]
-        file_name = 'model_epoch_{}_file_{}.h5'.format(epoch, fileno)
+        file_name = "model_epoch_{}_file_{}.h5".format(epoch, fileno)
 
         model_path = subfolder + "/" + file_name
         return model_path
@@ -280,13 +283,16 @@ class IOHandler(object):
         """
         list_file = self.cfg.get_list_file()
         if list_file is None:
-            raise ValueError("No toml list file specified. Can not look up "
-                             "saved prediction")
+            raise ValueError(
+                "No toml list file specified. Can not look up " "saved prediction"
+            )
         list_name = os.path.splitext(os.path.basename(list_file))[0]
 
-        pred_filepath = self.get_subfolder("predictions") + \
-            '/pred_model_epoch_{}_file_{}_on_{}_val_file_{}.h5'.format(
-                epoch, fileno, list_name, pred_file_no)
+        pred_filepath = self.get_subfolder(
+            "predictions"
+        ) + "/pred_model_epoch_{}_file_{}_on_{}_val_file_{}.h5".format(
+            epoch, fileno, list_name, pred_file_no
+        )
 
         return pred_filepath
 
@@ -404,22 +410,29 @@ class IOHandler(object):
         file_sizes_full, error_file_sizes, file_sizes = {}, [], []
         for n, file_no_set in enumerate(self.yield_files(which)):
             # the number of samples in the n-th file of all inputs
-            file_sizes_full[n] = [h5_get_number_of_rows(
-                file, datasets=[self.cfg.key_y_values, self.cfg.key_x_values])
-                for file in file_no_set.values()]
-            if not file_sizes_full[n].count(file_sizes_full[n][0]) == \
-                    len(file_sizes_full[n]):
-                    error_file_sizes.append(n)
+            file_sizes_full[n] = [
+                h5_get_number_of_rows(file, datasets=[self.cfg.key_y_values])
+                for file in file_no_set.values()
+            ]
+            if not file_sizes_full[n].count(file_sizes_full[n][0]) == len(
+                file_sizes_full[n]
+            ):
+                error_file_sizes.append(n)
             else:
                 file_sizes.append(file_sizes_full[n][0])
 
         if len(error_file_sizes) != 0:
-            err_msg = "The files you gave for the different inputs of the model " \
-                      "do not all have the same number of samples!\n"
+            err_msg = (
+                "The files you gave for the different inputs of the model "
+                "do not all have the same number of samples!\n"
+            )
             for n in error_file_sizes:
-                err_msg += "File no {} in {} has the following files sizes " \
-                           "for the different inputs: {}\n".format(
-                            n, which, file_sizes_full[n])
+                err_msg += (
+                    "File no {} in {} has the following files sizes "
+                    "for the different inputs: {}\n".format(
+                        n, which, file_sizes_full[n]
+                    )
+                )
             raise ValueError(err_msg)
 
         return file_sizes
@@ -471,9 +484,9 @@ class IOHandler(object):
             yield files_dict
 
     def get_file(self, which, file_no):
-        """ Get a dict with the n-th files. """
+        """Get a dict with the n-th files."""
         files = self.get_local_files(which)
-        files_dict = {key: files[key][file_no-1] for key in files}
+        files_dict = {key: files[key][file_no - 1] for key in files}
         return files_dict
 
     def check_connections(self, model):
@@ -500,12 +513,15 @@ class IOHandler(object):
         y_values = info_blob["y_values"]
         layer_inputs = get_inputs(model)
         # keys: name of layers, values: shape of input
-        layer_inp_shapes = {key: layer_inputs[key].input_shape[0][1:]
-                            for key in layer_inputs}
+        layer_inp_shapes = {
+            key: layer_inputs[key].input_shape[0][1:] for key in layer_inputs
+        }
         list_inp_shapes = self.get_n_bins()
 
-        print("The data in the files of the toml list have the following "
-              "names and shapes:")
+        print(
+            "The data in the files of the toml list have the following "
+            "names and shapes:"
+        )
         for list_key in list_inp_shapes:
             print("\t{}\t{}".format(list_key, list_inp_shapes[list_key]))
 
@@ -518,8 +534,10 @@ class IOHandler(object):
                 modi_key: tuple(modified_xs[modi_key].shape)[1:]
                 for modi_key in modified_xs
             }
-            print("\nAfter applying your sample modifier, they have the "
-                  "following names and shapes:")
+            print(
+                "\nAfter applying your sample modifier, they have the "
+                "following names and shapes:"
+            )
             for list_key in modified_shapes:
                 print("\t{}\t{}".format(list_key, modified_shapes[list_key]))
             list_inp_shapes = modified_shapes
@@ -545,38 +563,47 @@ class IOHandler(object):
         else:
             print("\nInput check failed!")
             if len(err_inp_names) != 0:
-                err_msg_inp += "No matching input name from the input files " \
-                               "for input layer(s): " + (
-                                ", ".join(str(e) for e in err_inp_names) + "\n")
+                err_msg_inp += (
+                    "No matching input name from the input files "
+                    "for input layer(s): "
+                    + (", ".join(str(e) for e in err_inp_names) + "\n")
+                )
             if len(err_inp_shapes) != 0:
-                err_msg_inp += "Shapes of layers and labels do not match for " \
-                               "the following input layer(s): " + (
-                                ", ".join(str(e) for e in err_inp_shapes) + "\n")
+                err_msg_inp += (
+                    "Shapes of layers and labels do not match for "
+                    "the following input layer(s): "
+                    + (", ".join(str(e) for e in err_inp_shapes) + "\n")
+                )
             print("Error:", err_msg_inp)
 
         # ----------------------------------
         print("\nOutput check\n------------")
         # tuple of strings
         mc_names = y_values.dtype.names
-        print("The following {} label names are in the first file of the "
-              "toml list:".format(len(mc_names)))
+        print(
+            "The following {} label names are in the first file of the "
+            "toml list:".format(len(mc_names))
+        )
         print("\t" + ", ".join(str(name) for name in mc_names), end="\n\n")
 
         if self.cfg.label_modifier is not None:
             label_names = tuple(self.cfg.label_modifier(info_blob).keys())
-            print("The following {} labels get produced from them by your "
-                  "label_modifier:".format(len(label_names)))
+            print(
+                "The following {} labels get produced from them by your "
+                "label_modifier:".format(len(label_names))
+            )
             print("\t" + ", ".join(str(name) for name in label_names), end="\n\n")
         else:
             label_names = mc_names
-            print("You did not specify a label_modifier. The output layers "
-                  "will be provided with labels that match their name from "
-                  "the above.\n\n")
+            print(
+                "You did not specify a label_modifier. The output layers "
+                "will be provided with labels that match their name from "
+                "the above.\n\n"
+            )
 
         # tuple of strings
         loss_names = tuple(model.output_names)
-        print("Your model has the following {} output layers:".format(
-            len(loss_names)))
+        print("Your model has the following {} output layers:".format(len(loss_names)))
         print("\t" + ", ".join(str(name) for name in loss_names), end="\n\n")
 
         err_out_names = []
@@ -590,9 +617,11 @@ class IOHandler(object):
         else:
             print("Output check failed!")
             if len(err_out_names) != 0:
-                err_msg_out += "No matching label name from the input files " \
-                               "for output layer(s): " + (
-                                ", ".join(str(e) for e in err_out_names) + "\n")
+                err_msg_out += (
+                    "No matching label name from the input files "
+                    "for output layer(s): "
+                    + (", ".join(str(e) for e in err_out_names) + "\n")
+                )
             print("Error:", err_msg_out)
 
         err_msg = err_msg_inp + err_msg_out
@@ -656,22 +685,24 @@ class IOHandler(object):
         return input_shapes
 
     def print_log(self, lines, logging=True):
-        """ Print and also log to the full log file. """
+        """Print and also log to the full log file."""
         if isinstance(lines, str):
-            lines = [lines, ]
+            lines = [
+                lines,
+            ]
 
         if not logging:
             for line in lines:
                 print(line)
         else:
-            full_log_file = self.cfg.output_folder + 'log.txt'
-            with open(full_log_file, 'a+') as f_out:
+            full_log_file = self.cfg.output_folder + "log.txt"
+            with open(full_log_file, "a+") as f_out:
                 for line in lines:
                     f_out.write(line + "\n")
                     print(line)
 
     def get_epoch_float(self, epoch, fileno):
-        """ Make a float value out of epoch/fileno. """
+        """Make a float value out of epoch/fileno."""
         # calculate the fraction of samples per file compared to all files,
         # e.g. [100, 50, 50] --> [0.5, 0.75, 1]
         file_sizes = self.get_file_sizes("train")
@@ -700,8 +731,10 @@ class IOHandler(object):
             The learning rate that will be used for the given epoch/fileno.
 
         """
-        error_msg = "The learning rate must be either a float, a tuple of " \
-                    "two floats or a function."
+        error_msg = (
+            "The learning rate must be either a float, a tuple of "
+            "two floats or a function."
+        )
         no_train_files = self.get_no_of_files("train")
         user_lr = self.cfg.learning_rate
 
@@ -712,7 +745,7 @@ class IOHandler(object):
             lr_table = np.genfromtxt(lr_file)
 
             if len(lr_table.shape) == 1:
-                lr_table = lr_table.reshape((1, ) + lr_table.shape)
+                lr_table = lr_table.reshape((1,) + lr_table.shape)
 
             if len(lr_table.shape) != 2 or lr_table.shape[1] != 3:
                 raise ValueError("Invalid lr.csv format")
@@ -728,7 +761,8 @@ class IOHandler(object):
                     lr = table_epoch[1]
             if lr is None:
                 raise ValueError(
-                    "csv learning rate not specified for epoch {}".format(epoch))
+                    "csv learning rate not specified for epoch {}".format(epoch)
+                )
             return lr
 
         try:
@@ -745,11 +779,12 @@ class IOHandler(object):
             lr_decay = float(user_lr[1])
             if length != 2:
                 raise LookupError(
-                    "{} (Your tuple has length {})".format(error_msg,
-                                                           len(user_lr)))
+                    "{} (Your tuple has length {})".format(error_msg, len(user_lr))
+                )
 
             lr = lr_init * (1 - lr_decay) ** (
-                        (epoch[1] - 1) + (epoch[0] - 1) * no_train_files)
+                (epoch[1] - 1) + (epoch[0] - 1) * no_train_files
+            )
             return lr
         except (ValueError, TypeError):
             pass
@@ -758,14 +793,17 @@ class IOHandler(object):
             # Callable => User defined function
             n_params = len(signature(user_lr).parameters)
             if n_params != 2:
-                raise TypeError("A custom learning rate function must have two "
-                                "input parameters: The epoch and the file number. "
-                                "(yours has {})".format(n_params))
+                raise TypeError(
+                    "A custom learning rate function must have two "
+                    "input parameters: The epoch and the file number. "
+                    "(yours has {})".format(n_params)
+                )
             lr = user_lr(epoch[0], epoch[1])
             return lr
         except (ValueError, TypeError):
-            raise TypeError("{} (You gave {} of type {}) ".format(
-                error_msg, user_lr, type(user_lr)))
+            raise TypeError(
+                "{} (You gave {} of type {}) ".format(error_msg, user_lr, type(user_lr))
+            )
 
 
 def split_name_of_predfile(file):
@@ -818,17 +856,17 @@ def h5_get_number_of_rows(h5_filepath, datasets=None):
         If the given datasets do not have the same no of rows.
 
     """
-    with h5py.File(h5_filepath, 'r') as f:
+    with h5py.File(h5_filepath, "r") as f:
         if datasets is None:
             datasets = [x for x in list(f.keys())]
 
         number_of_rows = [f[dataset].shape[0] for dataset in datasets]
     if not number_of_rows.count(number_of_rows[0]) == len(number_of_rows):
-        err_msg = "Datasets do not have the same number of samples " \
-                  "in file " + h5_filepath
+        err_msg = (
+            "Datasets do not have the same number of samples " "in file " + h5_filepath
+        )
         for i, dataset in enumerate(datasets):
-            err_msg += "\nDataset: {}\tSamples: {}".format(dataset,
-                                                           number_of_rows[i])
+            err_msg += "\nDataset: {}\tSamples: {}".format(dataset, number_of_rows[i])
         raise AssertionError(err_msg)
     return number_of_rows[0]
 
@@ -848,7 +886,7 @@ def use_local_tmpdir(files):
         Dict with updated SSD/scratch filepaths.
 
     """
-    local_scratch_path = os.environ['TMPDIR']
+    local_scratch_path = os.environ["TMPDIR"]
     files_ssd = {}
 
     for input_key in files:
@@ -856,12 +894,11 @@ def use_local_tmpdir(files):
         new_pathes = []
         for f_path in old_pathes:
             # copy to /scratch node-local SSD
-            f_path_ssd = os.path.join(local_scratch_path,
-                                      os.path.basename(f_path))
+            f_path_ssd = os.path.join(local_scratch_path, os.path.basename(f_path))
             print("Copying", f_path, "\nto", f_path_ssd)
             shutil.copy2(f_path, local_scratch_path)
             new_pathes.append(f_path_ssd)
         files_ssd[input_key] = tuple(new_pathes)
 
-    print('Finished copying to local tmpdir folder.')
+    print("Finished copying to local tmpdir folder.")
     return files_ssd
