@@ -59,22 +59,28 @@ class TrainfileLogger:
         if self._widths is None:
             raise ValueError("Can not log: .level_file has to be called first")
         if len(values) != len(self.column_names):
-            raise ValueError("Can not log: Expected {} values, but got "
-                             "{}".format(len(self.column_names), len(values)))
+            raise ValueError(
+                "Can not log: Expected {} values, but got "
+                "{}".format(len(self.column_names), len(values))
+            )
 
         line = self._gen_line_str(values, self._widths)[0]
         self.log_file.write(line + "\n")
 
     def _gen_line_str(self, data, widths=None, seperator=" | "):
-        line, widths = gen_line_str(data,
-                                    widths=widths,
-                                    seperator=seperator,
-                                    float_precision=self.float_precision,
-                                    minimum_cell_width=self.minimum_cell_width)
+        line, widths = gen_line_str(
+            data,
+            widths=widths,
+            seperator=seperator,
+            float_precision=self.float_precision,
+            minimum_cell_width=self.minimum_cell_width,
+        )
         return line, widths
 
 
-def gen_line_str(data, widths=None, seperator=" | ", float_precision=4, minimum_cell_width=9):
+def gen_line_str(
+    data, widths=None, seperator=" | ", float_precision=4, minimum_cell_width=9
+):
     """
     Generate a line in nice human readable format,
     consisting of multiple spaced and seperated cells.
@@ -109,7 +115,8 @@ def gen_line_str(data, widths=None, seperator=" | ", float_precision=4, minimum_
 
     """
     cells, new_widths = gen_line_cells(
-        data, widths, float_precision, minimum_cell_width)
+        data, widths, float_precision, minimum_cell_width
+    )
     line = seperator.join(str(cell) for cell in cells)
     return line, new_widths
 
@@ -135,7 +142,7 @@ def gen_line_cells(data, widths=None, float_precision=4, minimum_cell_width=9):
     for i, entry in enumerate(data):
         # If entry is a number, round to given precision and make it a string
         if not isinstance(entry, str):
-            entry = format(float(entry), "."+str(float_precision)+"g")
+            entry = format(float(entry), "." + str(float_precision) + "g")
 
         if widths is None:
             cell_width = max(minimum_cell_width, len(entry))
@@ -143,7 +150,7 @@ def gen_line_cells(data, widths=None, float_precision=4, minimum_cell_width=9):
         else:
             cell_width = widths[i]
 
-        cell_cont = format(entry, "<"+str(cell_width))
+        cell_cont = format(entry, "<" + str(cell_width))
         cells.append(cell_cont)
 
     return cells, new_widths
@@ -161,6 +168,7 @@ class SummaryLogger:
         Keras model containing the metrics to plot.
 
     """
+
     def __init__(self, orga, model):
         self.orga = orga
         self.model = model
@@ -169,7 +177,7 @@ class SummaryLogger:
         # Precision to which floats are rounded if they appear in data.
         self.float_precision = 6
 
-        self.logfile_name = orga.cfg.output_folder + 'summary.txt'
+        self.logfile_name = orga.cfg.output_folder + "summary.txt"
         self.temp_filepath = orga.cfg.output_folder + "/.temp_summary.txt"
 
     def write_line(self, epoch_float, lr, history_train=None, history_val=None):
@@ -203,7 +211,8 @@ class SummaryLogger:
         """
         if history_val is None and history_train is None:
             raise ValueError(
-                "Can not summary log when both train and val history are None")
+                "Can not summary log when both train and val history are None"
+            )
 
         widths = self._init_writing()
 
@@ -238,7 +247,10 @@ class SummaryLogger:
         self._save_line(line, update_line)
 
     def _get_column_names(self):
-        column_names = ["Epoch", "LR", ]
+        column_names = [
+            "Epoch",
+            "LR",
+        ]
         for metric_name in self.model.metrics_names:
             column_names.append("train_" + str(metric_name))
             column_names.append("val_" + str(metric_name))
@@ -250,17 +262,16 @@ class SummaryLogger:
             if not set(column_names) == set(file_column_names):
                 raise NameError(
                     "Can not log to summary: column names differ (from model: "
-                    "{}, from summary file: {}".format(column_names,
-                                                       file_column_names))
+                    "{}, from summary file: {}".format(column_names, file_column_names)
+                )
             column_names = file_column_names
 
         return column_names
 
     def _save_line(self, line, update=False):
-        """ Write a line in the summary file. If update, overwrite the last line.
-        """
+        """Write a line in the summary file. If update, overwrite the last line."""
         if not update:
-            with open(self.logfile_name, 'a+') as logfile:
+            with open(self.logfile_name, "a+") as logfile:
                 logfile.write(line + "\n")
 
         else:
@@ -270,7 +281,7 @@ class SummaryLogger:
             lines[-1] = line + "\n"
 
             # make new summary file as a temp
-            with open(self.temp_filepath, 'w') as temp_file:
+            with open(self.temp_filepath, "w") as temp_file:
                 for old_line in lines:
                     temp_file.write(old_line)
 
@@ -294,30 +305,36 @@ class SummaryLogger:
         """
         column_names = self._get_column_names()
         headline, widths = self._gen_line_str(column_names)
-        if not os.path.isfile(self.logfile_name) or \
-                os.stat(self.logfile_name).st_size == 0:
+        if (
+            not os.path.isfile(self.logfile_name)
+            or os.stat(self.logfile_name).st_size == 0
+        ):
 
             vline = ["-" * width for width in widths]
             vertical_line = self._gen_line_str(vline, widths, seperator="-+-")[0]
-            with open(self.logfile_name, 'a+') as logfile:
+            with open(self.logfile_name, "a+") as logfile:
                 logfile.write(headline + "\n")
                 logfile.write(vertical_line + "\n")
 
         return widths
 
     def _gen_line_str(self, data, widths=None, seperator=" | "):
-        line, widths = gen_line_str(data,
-                                    widths=widths,
-                                    seperator=seperator,
-                                    float_precision=self.float_precision,
-                                    minimum_cell_width=self.minimum_cell_width)
+        line, widths = gen_line_str(
+            data,
+            widths=widths,
+            seperator=seperator,
+            float_precision=self.float_precision,
+            minimum_cell_width=self.minimum_cell_width,
+        )
         return line, widths
 
     def _gen_line_cells(self, data, widths=None):
-        cells, widths = gen_line_cells(data,
-                                       widths=widths,
-                                       float_precision=self.float_precision,
-                                       minimum_cell_width=self.minimum_cell_width)
+        cells, widths = gen_line_cells(
+            data,
+            widths=widths,
+            float_precision=self.float_precision,
+            minimum_cell_width=self.minimum_cell_width,
+        )
         return cells, widths
 
 
@@ -357,8 +374,10 @@ def merge_arrays(base, supp, exclude=None):
 
         else:
             raise ValueError(
-                "Cannot merge arrays at index {}: Base {}, supplement {}"
-                .format(i, base[i], supp[i]))
+                "Cannot merge arrays at index {}: Base {}, supplement {}".format(
+                    i, base[i], supp[i]
+                )
+            )
     return base
 
 
@@ -382,6 +401,7 @@ class BatchLogger(ks.callbacks.Callback):
         Reset internal state of metric after eveery batch?
 
     """
+
     def __init__(self, orga, epoch, reset_metrics=True):
         super().__init__()
         self.reset_metrics = reset_metrics
@@ -392,9 +412,11 @@ class BatchLogger(ks.callbacks.Callback):
         # settings (read from orga)
         self.display = orga.cfg.train_logger_display
         self.flush = orga.cfg.train_logger_flush
-        self.logfile_name = '{}/log_epoch_{}_file_{}.txt'.format(
+        self.logfile_name = "{}/log_epoch_{}_file_{}.txt".format(
             orga.io.get_subfolder("train_log", create=True),
-            self.epoch_number, self.f_number)
+            self.epoch_number,
+            self.f_number,
+        )
         self.batchsize = orga.cfg.batchsize
         self.file_sizes = np.array(orga.io.get_file_sizes("train"))
 
@@ -404,7 +426,7 @@ class BatchLogger(ks.callbacks.Callback):
         self.total_batches = np.sum(file_batches)
         # no of batches seen in previous files
         if self.f_number == 1:
-            self.previous_batches = 0.
+            self.previous_batches = 0.0
         elif self.f_number > 1:
             self.previous_batches = np.cumsum(file_batches)[self.f_number - 2]
         else:
@@ -422,7 +444,7 @@ class BatchLogger(ks.callbacks.Callback):
         self.epoch_initialized = False
 
     def initialize_epoch(self):
-        """ Start a new logfile and prepare the logger. """
+        """Start a new logfile and prepare the logger."""
         # no of seen batches in this epoch
         self.seen = 0
         # list of stored lines, so that multiple can be written at once
@@ -472,13 +494,15 @@ class BatchLogger(ks.callbacks.Callback):
         self.file.close()
 
     def _write_line(self):
-        """ Write a line with the metrics for current status and reset metrics.
-        """
+        """Write a line with the metrics for current status and reset metrics."""
         # The fraction is shifted by self.display / 2., so that it is in
         # the middle of the samples
-        batch_frctn = self.epoch_number - 1 + (
-                self.previous_batches + self.seen
-                - self.display / 2.) / self.total_batches
+        batch_frctn = (
+            self.epoch_number
+            - 1
+            + (self.previous_batches + self.seen - self.display / 2.0)
+            / self.total_batches
+        )
 
         line_data = [self.seen, batch_frctn]
         for metric in self.model.metrics_names:
@@ -492,8 +516,8 @@ class BatchLogger(ks.callbacks.Callback):
         os.fsync(self.file.fileno())
 
     def _write_head(self):
-        """ write column names for all losses / metrics """
-        column_names = ['Batch', 'Batch_float']
+        """write column names for all losses / metrics"""
+        column_names = ["Batch", "Batch_float"]
         for metric in self.model.metrics_names:
             column_names.append(metric)
         self._logger = TrainfileLogger(self.file, column_names)
@@ -514,10 +538,10 @@ def log_start_training(orga):
     lines = []
     log = lines.append
 
-    log('-'*60)
-    time = datetime.now().strftime('%Y-%m-%d  %H:%M:%S')
-    log('-'*19 + " {} ".format(time) + '-'*19)
-    log('-'*10 + " orcanet version " + str(orcanet.__version__))
+    log("-" * 60)
+    time = datetime.now().strftime("%Y-%m-%d  %H:%M:%S")
+    log("-" * 19 + " {} ".format(time) + "-" * 19)
+    log("-" * 10 + " orcanet version " + str(orcanet.__version__))
     log("\nTraining run started with the following configuration:\n")
 
     log("Output folder:\t" + orga.cfg.output_folder)
@@ -544,11 +568,13 @@ def log_start_training(orga):
 
 
 def log_start_validation(orga):
-    """ Log filenames used for validation. """
+    """Log filenames used for validation."""
     line = "Validation"
     orga.io.print_log(line)
     orga.io.print_log("-" * len(line))
-    lines = ['Inputs and files:', ]
+    lines = [
+        "Inputs and files:",
+    ]
     for input_name, input_files in orga.io.get_local_files("val").items():
         line = "   " + input_name + ":\t"
         for i, input_file in enumerate(input_files):
