@@ -54,6 +54,7 @@ class ModelBuilder:
         Compile a model with the optimizer settings given in the model_file.
 
     """
+
     def __init__(self, model_file, **custom_blocks):
         """
         Read out parameters for creating models with OrcaNet from a toml file.
@@ -73,7 +74,7 @@ class ModelBuilder:
         try:
             if "model" in file_content:
                 model_args = file_content["model"]
-                self.configs = model_args.pop('blocks')
+                self.configs = model_args.pop("blocks")
                 self.input_opts = model_args.pop("input_opts", {})
                 self.defaults = model_args
 
@@ -95,8 +96,9 @@ class ModelBuilder:
                 option = e.args[0]
             else:
                 option = e.args
-            raise KeyError("Missing parameter in toml model file: "
-                           + str(option)) from None
+            raise KeyError(
+                "Missing parameter in toml model file: " + str(option)
+            ) from None
 
     def _compat_init(self, file_content):
         warnings.warn(
@@ -109,7 +111,7 @@ class ModelBuilder:
             arch = body.pop("architecture")
             if arch != "single":
                 raise ValueError("architecture keyword is deprecated")
-        self.configs = body.pop('blocks')
+        self.configs = body.pop("blocks")
         self.defaults = body
 
         if "head" in file_content:
@@ -146,11 +148,14 @@ class ModelBuilder:
 
         """
         if orga.cfg.fixed_batchsize:
-            if "batchsize" in self.input_opts and \
-                    self.input_opts["batchsize"] != orga.cfg.batchsize:
+            if (
+                "batchsize" in self.input_opts
+                and self.input_opts["batchsize"] != orga.cfg.batchsize
+            ):
                 raise ValueError(
                     f"Batchsize in input_opts is {self.input_opts['batchsize']}, "
-                    f"but in cfg its {orga.cfg.batchsize}")
+                    f"but in cfg its {orga.cfg.batchsize}"
+                )
             self.input_opts["batchsize"] = orga.cfg.batchsize
 
         with orga.get_strategy().scope():
@@ -166,10 +171,9 @@ class ModelBuilder:
         model.summary()
         return model
 
-    def build_with_input(self, input_shapes,
-                         compile_model=True,
-                         custom_objects=None,
-                         verbose=False):
+    def build_with_input(
+        self, input_shapes, compile_model=True, custom_objects=None, verbose=False
+    ):
         """
         Build the network with given input shapes.
 
@@ -192,8 +196,11 @@ class ModelBuilder:
 
         """
         builder = BlockBuilder(
-            self.defaults, verbose=verbose, input_opts=self.input_opts,
-            **self.custom_blocks)
+            self.defaults,
+            verbose=verbose,
+            input_opts=self.input_opts,
+            **self.custom_blocks,
+        )
         model = builder.build(input_shapes, self.configs)
 
         if compile_model:
@@ -284,21 +291,21 @@ class ModelBuilder:
         loss_functions, loss_weights, loss_metrics = {}, {}, {}
         for layer_name, layer_info in self.compile_opt.items():
             # Replace the str function name with actual function if it is custom
-            loss_function = layer_info['function']
+            loss_function = layer_info["function"]
             if custom_objects is not None and loss_function in custom_objects:
                 loss_function = custom_objects[loss_function]
             loss_functions[layer_name] = loss_function
 
             # Use given weight, else use default weight of 1
-            if 'weight' in layer_info:
-                weight = layer_info['weight']
+            if "weight" in layer_info:
+                weight = layer_info["weight"]
             else:
                 weight = 1.0
             loss_weights[layer_name] = weight
 
             # Use given metrics, else use no metrics
-            if 'metrics' in layer_info:
-                metrics = layer_info['metrics']
+            if "metrics" in layer_info:
+                metrics = layer_info["metrics"]
             else:
                 metrics = []
             if custom_objects is not None:
@@ -309,8 +316,12 @@ class ModelBuilder:
             loss_metrics[layer_name] = metrics
 
         optimizer = self._get_optimizer()
-        model.compile(loss=loss_functions, optimizer=optimizer,
-                      metrics=loss_metrics, loss_weights=loss_weights)
+        model.compile(
+            loss=loss_functions,
+            optimizer=optimizer,
+            metrics=loss_metrics,
+            loss_weights=loss_weights,
+        )
         return model
 
     def log_model_properties(self, orga):
@@ -318,51 +329,50 @@ class ModelBuilder:
         Writes the compile_opt config to the full log file.
         """
         lines = list()
-        lines.append('-' * 60)
-        time = datetime.now().strftime('%Y-%m-%d  %H:%M:%S')
-        lines.append('-' * 19 + " {} ".format(time) + '-' * 19)
-        lines.append("A model has been built using the model builder with the following configurations:\n")
-        lines.append('Loss functions: ')
+        lines.append("-" * 60)
+        time = datetime.now().strftime("%Y-%m-%d  %H:%M:%S")
+        lines.append("-" * 19 + " {} ".format(time) + "-" * 19)
+        lines.append(
+            "A model has been built using the model builder with the following configurations:\n"
+        )
+        lines.append("Loss functions: ")
         for key in self.compile_opt:
-            lines.append(key + ': ' + str(self.compile_opt[key]))
-        lines.append('\n')
+            lines.append(key + ": " + str(self.compile_opt[key]))
+        lines.append("\n")
         orga.io.print_log(lines)
 
     def _get_optimizer(self):
         if not isinstance(self.optimizer, str):
             if self.optimizer_args:
                 warnings.warn(
-                    "Custom callback used, optimizer_args are ignored: " +
-                    str(self.optimizer_args)
+                    "Custom callback used, optimizer_args are ignored: "
+                    + str(self.optimizer_args)
                 )
             return self.optimizer
-        if self.optimizer == 'adam':
+        if self.optimizer == "adam":
             optimizer = get_adam(**self.optimizer_args)
-        elif self.optimizer == 'sgd':
+        elif self.optimizer == "sgd":
             optimizer = get_sgd(**self.optimizer_args)
         elif self.optimizer.startswith("keras:"):
-            optimizer = getattr(
-                ks.optimizers, self.optimizer.split("keras:")[-1]
-            )(**self.optimizer_args)
+            optimizer = getattr(ks.optimizers, self.optimizer.split("keras:")[-1])(
+                **self.optimizer_args
+            )
         else:
-            raise NameError('Unknown optimizer name ({})'.format(self.optimizer))
+            raise NameError("Unknown optimizer name ({})".format(self.optimizer))
         return optimizer
 
 
 def get_adam(beta_1=0.9, beta_2=0.999, epsilon=0.1, decay=0.0, **kwargs):
     # epsilon=1 for deep networks
-    return ks.optimizers.Adam(beta_1=beta_1,
-                              beta_2=beta_2,
-                              epsilon=epsilon,
-                              decay=decay,
-                              **kwargs)
+    return ks.optimizers.Adam(
+        beta_1=beta_1, beta_2=beta_2, epsilon=epsilon, decay=decay, **kwargs
+    )
 
 
 def get_sgd(momentum=0.9, decay=0, nesterov=True, **kwargs):
-    return ks.optimizers.SGD(momentum=momentum,
-                             decay=decay,
-                             nesterov=nesterov,
-                             **kwargs)
+    return ks.optimizers.SGD(
+        momentum=momentum, decay=decay, nesterov=nesterov, **kwargs
+    )
 
 
 def _change_dropout_rate(model, before_concat, after_concat=None):
@@ -405,6 +415,8 @@ def _change_dropout_rate(model, before_concat, after_concat=None):
         raise TypeError("Expected 1 Flatten layer but got " + str(concat_found))
     clone = ks.models.clone_model(model)
     clone.set_weights(model.get_weights())
-    print("Changed dropout rates of {} layers before and {} layers after "
-          "Concatenate.".format(ch_bef, ch_aft))
+    print(
+        "Changed dropout rates of {} layers before and {} layers after "
+        "Concatenate.".format(ch_bef, ch_aft)
+    )
     return clone
