@@ -8,6 +8,7 @@ class TestSequentialBuilder(TestCase):
     """
     Just build some models to see if there are embarrassing formatting errors.
     """
+
     def setUp(self):
         orca_dir = os.path.dirname(os.path.dirname(orcanet.model_builder.__file__))
         self.example_dir = os.path.join(orca_dir, "examples", "model_files")
@@ -16,10 +17,12 @@ class TestSequentialBuilder(TestCase):
             dimdict = {
                 2: get_input_shapes_2d,
                 3: get_input_shapes_3d,
-                "graph": get_input_shapes_graph}
+                "graph": get_input_shapes_graph,
+            }
             orga = Organizer(".")
             orga.io.get_input_shapes = dimdict[dims]
             return orga
+
         self.get_orga = get_orga
 
     def test_cnn(self):
