@@ -16,7 +16,8 @@ from orcanet_contrib.custom_objects import get_custom_objects
 
 
 class TestIntegration(tf.test.TestCase):
-    """ Run the actual training to see if it throws any errors. """
+    """Run the actual training to see if it throws any errors."""
+
     def setUp(self):
         """
         Make a .temp directory in the current working directory, generate
@@ -58,21 +59,31 @@ class TestIntegration(tf.test.TestCase):
         self.make_orga = make_orga
 
     def tearDown(self):
-        """ Remove the .temp directory. """
+        """Remove the .temp directory."""
         self.tdir.cleanup()
 
     def test_integration_zero_center(self):
-        """ Calculate the zero center image and check if it works properly. """
+        """Calculate the zero center image and check if it works properly."""
         orga = self.make_orga()
         xs_mean = orga.get_xs_mean()
-        target_xs_mean = np.ones(self.shape)/4
+        target_xs_mean = np.ones(self.shape) / 4
         self.assertTrue(np.allclose(xs_mean["testing_input"], target_xs_mean))
 
-        file = orga.cfg.zero_center_folder + "/" + orga.cfg._list_file + \
-            '_input_' + "testing_input" + '.npz'
-        zero_center_used_ip_files = np.load(file)['zero_center_used_ip_files']
-        self.assertTrue(np.array_equal(zero_center_used_ip_files,
-                                       orga.cfg._files_dict["train"]["testing_input"]))
+        file = (
+            orga.cfg.zero_center_folder
+            + "/"
+            + orga.cfg._list_file
+            + "_input_"
+            + "testing_input"
+            + ".npz"
+        )
+        zero_center_used_ip_files = np.load(file)["zero_center_used_ip_files"]
+        self.assertTrue(
+            np.array_equal(
+                zero_center_used_ip_files,
+                orga.cfg._files_dict["train"]["testing_input"],
+            )
+        )
 
     def test_integration_multi_input_model(self):
         """
@@ -95,7 +106,7 @@ class TestIntegration(tf.test.TestCase):
         orga.train_and_validate(initial_model, epochs=2)
 
         def test_learning_rate(epoch, fileno):
-            lr = 0.001 * (epoch + 0.1*fileno)
+            lr = 0.001 * (epoch + 0.1 * fileno)
             return lr
 
         def test_modifier(info_blob):
@@ -117,11 +128,13 @@ class TestFullExample(tf.test.TestCase):
     Test the full example in the examples folder, as it is used on the docs.
     Must go thorugh without any errors.
     """
+
     def test_full_example(self):
         init_dir = os.getcwd()
 
         example_dir = os.path.join(
-            os.path.dirname(orcanet.__path__[0]), "examples/full_example")
+            os.path.dirname(orcanet.__path__[0]), "examples/full_example"
+        )
         os.chdir(example_dir)
         sys.path.append(example_dir)
         output_dir = os.path.join(example_dir, "output")
@@ -152,14 +165,16 @@ def make_dummy_data(filepath1, filepath2, shape):
     xs1 = np.concatenate([np.ones((75,) + shape), np.zeros((75,) + shape)])
     xs2 = np.concatenate([np.ones((25,) + shape), np.zeros((225,) + shape)])
 
-    dtypes = [('dir_x', '<f8'), ]
+    dtypes = [
+        ("dir_x", "<f8"),
+    ]
     ys1 = np.ones((150, len(dtypes))).ravel().view(dtype=dtypes)
     ys2 = np.ones((250, len(dtypes))).ravel().view(dtype=dtypes)
 
     for xs, ys, filepath in ((xs1, ys1, filepath1), (xs2, ys2, filepath2)):
-        h5f = h5py.File(filepath, 'w')
-        h5f.create_dataset('x', data=xs, dtype='uint8')
-        h5f.create_dataset('y', data=ys, dtype=dtypes)
+        h5f = h5py.File(filepath, "w")
+        h5f.create_dataset("x", data=xs, dtype="uint8")
+        h5f.create_dataset("y", data=ys, dtype=dtypes)
         h5f.close()
 
 
@@ -167,7 +182,7 @@ def label_modifier(info_blob):
     y_values = info_blob["y_values"]
     ys = dict()
 
-    ys['dx'], ys['dx_err'] = y_values['dir_x'], y_values['dir_x']
+    ys["dx"], ys["dx_err"] = y_values["dir_x"], y_values["dir_x"]
 
     for key_label in ys:
         ys[key_label] = ys[key_label].astype(np.float32)
