@@ -18,7 +18,8 @@ class TestInceptionBlockV2(TestCase):
             filters_3x3dbl=(7, 8),
         )(self.inp_2d)
         self.assertSequenceEqual(
-            tf.keras.Model(self.inp_2d, x).output_shape, (None, 10, 10, 21))
+            tf.keras.Model(self.inp_2d, x).output_shape, (None, 10, 10, 21)
+        )
 
     def test_shape_2d_strides(self):
         x = layer_blocks.InceptionBlockV2(
@@ -30,7 +31,8 @@ class TestInceptionBlockV2(TestCase):
             strides=2,
         )(self.inp_2d)
         self.assertSequenceEqual(
-            tf.keras.Model(self.inp_2d, x).output_shape, (None, 5, 5, 15))
+            tf.keras.Model(self.inp_2d, x).output_shape, (None, 5, 5, 15)
+        )
 
     def test_shape_3d(self):
         x = layer_blocks.InceptionBlockV2(
@@ -42,7 +44,8 @@ class TestInceptionBlockV2(TestCase):
             strides=1,
         )(self.inp_3d)
         self.assertSequenceEqual(
-            tf.keras.Model(self.inp_3d, x).output_shape, (None, 10, 10, 10, 21))
+            tf.keras.Model(self.inp_3d, x).output_shape, (None, 10, 10, 10, 21)
+        )
 
     def test_shape_3d_strides(self):
         x = layer_blocks.InceptionBlockV2(
@@ -54,7 +57,8 @@ class TestInceptionBlockV2(TestCase):
             strides=2,
         )(self.inp_3d)
         self.assertSequenceEqual(
-            tf.keras.Model(self.inp_3d, x).output_shape, (None, 5, 5, 5, 15))
+            tf.keras.Model(self.inp_3d, x).output_shape, (None, 5, 5, 5, 15)
+        )
 
     def test_2d_params(self):
         x = layer_blocks.InceptionBlockV2(
@@ -64,8 +68,7 @@ class TestInceptionBlockV2(TestCase):
             filters_3x3=(5, 6),
             filters_3x3dbl=(7, 8),
         )(self.inp_2d)
-        self.assertEqual(
-            tf.keras.Model(self.inp_2d, x).count_params(), 450)
+        self.assertEqual(tf.keras.Model(self.inp_2d, x).count_params(), 450)
 
     def test_2d_params_stride(self):
         x = layer_blocks.InceptionBlockV2(
@@ -76,8 +79,7 @@ class TestInceptionBlockV2(TestCase):
             filters_3x3dbl=(7, 8),
             strides=2,
         )(self.inp_2d)
-        self.assertEqual(
-            tf.keras.Model(self.inp_2d, x).count_params(), 436)
+        self.assertEqual(tf.keras.Model(self.inp_2d, x).count_params(), 436)
 
 
 class TestConvBlock(TestCase):
@@ -119,7 +121,9 @@ class TestConvBlock(TestCase):
 
         self.assertEqual(model.count_params(), 110)
         self.assertSequenceEqual(model.output_shape, (None, 8, 4, 4, 11))
-        target_layers = [tf.keras.layers.InputLayer] + [tf.keras.layers.TimeDistributed] * 5
+        target_layers = [tf.keras.layers.InputLayer] + [
+            tf.keras.layers.TimeDistributed
+        ] * 5
 
         for layer, target_layer in zip(model.layers, target_layers):
             self.assertIsInstance(layer, target_layer)
@@ -180,7 +184,9 @@ class TestOutputRegNormalSplit(TestOutputRegNormal):
             output_neurons=3,
             output_name="test",
             unit_list=[5, 5],
-            sigma_unit_list=[3, ],
+            sigma_unit_list=[
+                3,
+            ],
             mu_activation="relu",
             transition="keras:Flatten",
         )(inp)
@@ -196,7 +202,9 @@ class TestOutputRegNormalSplit(TestOutputRegNormal):
 
     def test_output_shape(self):
         for i in range(len(self.targets["output_shape"])):
-            self.assertTupleEqual(self.model.output_shape[i], self.targets["output_shape"][i])
+            self.assertTupleEqual(
+                self.model.output_shape[i], self.targets["output_shape"][i]
+            )
 
 
 class TestResnetBnetBlock(TestOutputRegNormal):
