@@ -6,16 +6,22 @@ import orcanet.lib.losses as on_losses
 class TestLklNormal(tf.test.TestCase):
     def setUp(self):
         self.loss_func = on_losses.lkl_normal
-        self.y_pred = tf.constant([
-            [[0], [1]],
-            [[1], [1]],
-            [[2], [2]],
-        ], dtype="float32")  # shape (3, 2, 1)
-        self.y_true = tf.constant([
-            [[0], [0]],
-            [[0], [0]],
-            [[0], [0]],
-        ], dtype="float32")
+        self.y_pred = tf.constant(
+            [
+                [[0], [1]],
+                [[1], [1]],
+                [[2], [2]],
+            ],
+            dtype="float32",
+        )  # shape (3, 2, 1)
+        self.y_true = tf.constant(
+            [
+                [[0], [0]],
+                [[0], [0]],
+                [[0], [0]],
+            ],
+            dtype="float32",
+        )
 
         self.target = tf.constant([[0.9189385], [1.4189385], [2.1120858]])
 
