@@ -17,8 +17,7 @@ class TetstZeroCenter(TestCase):
     def setUp(self):
         # Pathes
         # Temporary output folder
-        self.temp_dir = os.path.join(os.path.dirname(__file__),
-                                     ".temp", "nn_utilities")
+        self.temp_dir = os.path.join(os.path.dirname(__file__), ".temp", "nn_utilities")
         self.output_folder = os.path.join(self.temp_dir, "model")
         self.data_folder = os.path.join(os.path.dirname(__file__), "data")
 
@@ -33,7 +32,7 @@ class TetstZeroCenter(TestCase):
         # Make dummy data
         self.train_inp_A = (
             self.temp_dir + "/train1_A.h5",
-            self.temp_dir + "/train2_A.h5"
+            self.temp_dir + "/train2_A.h5",
         )
         self.train_inp_B = (
             self.temp_dir + "/train1_B.h5",
@@ -57,11 +56,11 @@ class TetstZeroCenter(TestCase):
         self.orga = orga
 
     def tearDown(self):
-        """ Remove the .temp directory. """
+        """Remove the .temp directory."""
         shutil.rmtree(self.temp_dir)
 
     def test_load_zero_center(self):
-        """ Calculate the zero center image and check if it works properly. """
+        """Calculate the zero center image and check if it works properly."""
         orga = self.orga
         xs_mean = load_zero_center_data(orga, logging=False)
 
@@ -72,12 +71,20 @@ class TetstZeroCenter(TestCase):
 
         self._check_dict_ndarray(xs_mean, target)
 
-        file_a = orga.cfg.zero_center_folder + "/" + orga.cfg._list_file + \
-            '_input_testing_input_A.npz'
-        file_b = orga.cfg.zero_center_folder + "/" + orga.cfg._list_file + \
-            '_input_testing_input_B.npz'
-        used_files_a = np.load(file_a)['zero_center_used_ip_files']
-        used_files_b = np.load(file_b)['zero_center_used_ip_files']
+        file_a = (
+            orga.cfg.zero_center_folder
+            + "/"
+            + orga.cfg._list_file
+            + "_input_testing_input_A.npz"
+        )
+        file_b = (
+            orga.cfg.zero_center_folder
+            + "/"
+            + orga.cfg._list_file
+            + "_input_testing_input_B.npz"
+        )
+        used_files_a = np.load(file_a)["zero_center_used_ip_files"]
+        used_files_b = np.load(file_b)["zero_center_used_ip_files"]
         self.assertTrue(np.array_equal(used_files_a, self.train_inp_A))
         self.assertTrue(np.array_equal(used_files_b, self.train_inp_B))
 
@@ -86,8 +93,8 @@ class TetstZeroCenter(TestCase):
         xs_mean = load_zero_center_data(orga, logging=False)
 
         self._check_dict_ndarray(xs_mean, target)
-        used_files_a = np.load(file_a)['zero_center_used_ip_files']
-        used_files_b = np.load(file_b)['zero_center_used_ip_files']
+        used_files_a = np.load(file_a)["zero_center_used_ip_files"]
+        used_files_b = np.load(file_b)["zero_center_used_ip_files"]
         self.assertTrue(np.array_equal(used_files_a, self.train_inp_A))
         self.assertTrue(np.array_equal(used_files_b, self.train_inp_B))
 
@@ -101,15 +108,17 @@ class TestModel(TestCase):
     def setUp(self):
         self.layer_names = ["inp1", "inp2", "mid", "outp"]
 
-        inp1 = layers.Input(shape=(2, ), name=self.layer_names[0])
-        inp2 = layers.Input(shape=(3, ), name=self.layer_names[1])
+        inp1 = layers.Input(shape=(2,), name=self.layer_names[0])
+        inp2 = layers.Input(shape=(3,), name=self.layer_names[1])
 
         conc = layers.Concatenate()([inp1, inp2])
 
-        intermed = layers.Dense(2,
-                                name=self.layer_names[2],
-                                bias_initializer="Ones",
-                                kernel_initializer="Ones")(conc)
+        intermed = layers.Dense(
+            2,
+            name=self.layer_names[2],
+            bias_initializer="Ones",
+            kernel_initializer="Ones",
+        )(conc)
         outp = layers.Dense(1, name=self.layer_names[3])(intermed)
 
         self.model = Model([inp1, inp2], outp)
@@ -151,17 +160,29 @@ def make_dummy_data(filepath1, filepath2, shape, mode=1):
     else:
         raise AssertionError
 
-    dtypes = [('event_id', '<f8'), ('particle_type', '<f8'), ('energy', '<f8'),
-              ('is_cc', '<f8'), ('bjorkeny', '<f8'), ('dir_x', '<f8'),
-              ('dir_y', '<f8'), ('dir_z', '<f8'), ('time_interaction', '<f8'),
-              ('run_id', '<f8'), ('vertex_pos_x', '<f8'), ('vertex_pos_y', '<f8'),
-              ('vertex_pos_z', '<f8'), ('time_residual_vertex', '<f8'),
-              ('prod_ident', '<f8'), ('group_id', '<i8')]
+    dtypes = [
+        ("event_id", "<f8"),
+        ("particle_type", "<f8"),
+        ("energy", "<f8"),
+        ("is_cc", "<f8"),
+        ("bjorkeny", "<f8"),
+        ("dir_x", "<f8"),
+        ("dir_y", "<f8"),
+        ("dir_z", "<f8"),
+        ("time_interaction", "<f8"),
+        ("run_id", "<f8"),
+        ("vertex_pos_x", "<f8"),
+        ("vertex_pos_y", "<f8"),
+        ("vertex_pos_z", "<f8"),
+        ("time_residual_vertex", "<f8"),
+        ("prod_ident", "<f8"),
+        ("group_id", "<i8"),
+    ]
     ys1 = np.ones((150, 16)).ravel().view(dtype=dtypes)
     ys2 = np.ones((250, 16)).ravel().view(dtype=dtypes)
 
     for xs, ys, filepath in ((xs1, ys1, filepath1), (xs2, ys2, filepath2)):
-        h5f = h5py.File(filepath, 'w')
-        h5f.create_dataset('x', data=xs, dtype='uint8')
-        h5f.create_dataset('y', data=ys, dtype=dtypes)
+        h5f = h5py.File(filepath, "w")
+        h5f.create_dataset("x", data=xs, dtype="uint8")
+        h5f.create_dataset("y", data=ys, dtype=dtypes)
         h5f.close()
