@@ -15,25 +15,27 @@ class RaiseOnNaN(ks.callbacks.Callback):
     """
     Callback that terminates training when a NaN loss is encountered.
     """
+
     def on_batch_end(self, batch, logs=None):
         logs = logs or {}
-        loss = logs.get('loss')
+        loss = logs.get("loss")
         if loss is not None:
             if np.isnan(loss) or np.isinf(loss):
                 warnings.warn(f"Input values:\n{batch}\n\nLogs:\n{logs}")
                 raise ValueError(
-                    f'Batch {batch}: Invalid loss {loss}, terminating training'
+                    f"Batch {batch}: Invalid loss {loss}, terminating training"
                 )
 
 
 class TimeModel(ks.callbacks.Callback):
-    """ Print how long the model took for processing batches. """
+    """Print how long the model took for processing batches."""
+
     def __init__(self, print_func=None):
         super().__init__()
         self.print_func = print_func
-        self._total_time = 0.
+        self._total_time = 0.0
         self._total_batches = 0
-        self._t_start = 0.
+        self._t_start = 0.0
 
     def start_time(self):
         self._t_start = time.time()
@@ -51,8 +53,7 @@ class TimeModel(ks.callbacks.Callback):
         print_func(f"\tTotal time:\t{self._total_time/60:.2f} min")
         if self._total_batches != 0:
             print_func(
-                f"\tPer batch:\t"
-                f"{1000 * self._total_time/self._total_batches:.5} ms"
+                f"\tPer batch:\t" f"{1000 * self._total_time/self._total_batches:.5} ms"
             )
 
     def on_train_batch_begin(self, batch, logs=None):
@@ -122,24 +123,39 @@ def load_zero_center_data(orga, logging=False):
         xs_mean_path = get_xs_mean_path(zero_center_folder, train_filepaths)
 
         if xs_mean_path is not None:
-            orga.io.print_log('{}:   Loading saved zero centering'.format(
-                input_key), logging)
+            orga.io.print_log(
+                "{}:   Loading saved zero centering".format(input_key), logging
+            )
             xs_mean_ip_i = np.load(xs_mean_path)["xs_mean"]
-            orga.io.print_log("\tLoaded file: {}".format(
-                os.path.basename(xs_mean_path)), logging)
+            orga.io.print_log(
+                "\tLoaded file: {}".format(os.path.basename(xs_mean_path)), logging
+            )
 
         else:
-            orga.io.print_log('{}:   Making new zero centering'.format(
-                input_key), logging)
+            orga.io.print_log(
+                "{}:   Making new zero centering".format(input_key), logging
+            )
 
             xs_mean_ip_i = make_xs_mean(train_filepaths, key_samples)
-            filename = zero_center_folder + train_files_list_name \
-                                          + '_input_' + str(input_key) + '.npz'
-            np.savez(filename, xs_mean=xs_mean_ip_i,
-                     zero_center_used_ip_files=train_filepaths)
+            filename = (
+                zero_center_folder
+                + train_files_list_name
+                + "_input_"
+                + str(input_key)
+                + ".npz"
+            )
+            np.savez(
+                filename,
+                xs_mean=xs_mean_ip_i,
+                zero_center_used_ip_files=train_filepaths,
+            )
 
-            orga.io.print_log('\tSaved as {} with shape {}'.format(
-                os.path.basename(filename), xs_mean_ip_i.shape), logging)
+            orga.io.print_log(
+                "\tSaved as {} with shape {}".format(
+                    os.path.basename(filename), xs_mean_ip_i.shape
+                ),
+                logging,
+            )
 
         xs_mean[input_key] = xs_mean_ip_i
 
@@ -175,10 +191,10 @@ def get_xs_mean_path(zero_center_folder, train_filepaths):
         os.mkdir(zero_center_folder)
 
     for file in os.listdir(zero_center_folder):
-        if not file.endswith('.npz'):
+        if not file.endswith(".npz"):
             continue
         file = zero_center_folder + file
-        used_ip_files = np.load(file)['zero_center_used_ip_files']
+        used_ip_files = np.load(file)["zero_center_used_ip_files"]
         if np.array_equal(used_ip_files, train_filepaths):
             xs_mean_path = file
             break
@@ -218,35 +234,39 @@ def make_xs_mean(filepaths, key_samples, total_memory=4e9):
     for filepath in filepaths:
 
         with h5py.File(filepath, "r") as file:
-            filesize = get_array_memsize(file['x'])
-            steps = int(np.ceil(filesize/total_memory))
+            filesize = get_array_memsize(file["x"])
+            steps = int(np.ceil(filesize / total_memory))
             n_rows = file[key_samples].shape[0]
             stepsize = int(n_rows / float(steps))
 
             # create xs_mean_arr that stores intermediate mean_temp results
-            xs_mean_arr = np.zeros((steps, ) + file['x'].shape[1:],
-                                   dtype=np.float64)
+            xs_mean_arr = np.zeros((steps,) + file["x"].shape[1:], dtype=np.float64)
             print("\tCalculating for file: " + filepath)
             for i in range(steps):
                 if i % 5 == 0:
-                    print('\t   Step ' + str(i) + " of " + str(steps))
+                    print("\t   Step " + str(i) + " of " + str(steps))
 
                 # for the last step, calculate mean till the end of the file
-                if i == steps-1 or steps == 1:
+                if i == steps - 1 or steps == 1:
                     xs_mean_temp = np.mean(
-                        file[key_samples][i * stepsize: n_rows],
-                        axis=0, dtype=np.float64)
+                        file[key_samples][i * stepsize : n_rows],
+                        axis=0,
+                        dtype=np.float64,
+                    )
                 else:
                     xs_mean_temp = np.mean(
-                        file[key_samples][i*stepsize: (i+1) * stepsize],
-                        axis=0, dtype=np.float64)
+                        file[key_samples][i * stepsize : (i + 1) * stepsize],
+                        axis=0,
+                        dtype=np.float64,
+                    )
 
                 xs_mean_arr[i] = xs_mean_temp
 
         print("\tDone!")
         # The mean for this file
-        xs_means.append(np.mean(xs_mean_arr, axis=0,
-                                dtype=np.float64).astype(np.float32))
+        xs_means.append(
+            np.mean(xs_mean_arr, axis=0, dtype=np.float64).astype(np.float32)
+        )
         # the number of samples in this file
         file_sizes.append(n_rows)
 
@@ -263,7 +283,7 @@ def get_array_memsize(array):
     :return: float memsize: size of the array in bytes.
     """
     shape = array.shape
-    n_numbers = reduce(lambda x, y: x*y, shape)  # number of entries in an array
+    n_numbers = reduce(lambda x, y: x * y, shape)  # number of entries in an array
     precision = 8  # Precision of each entry, typically uint8 for xs datasets
     memsize = (n_numbers * precision) / float(8)  # in bytes
 
